@@ -54,7 +54,11 @@ class IntervalFetching:
 
                     data_arr.append(union_df)
 
-                self.callback(*data_arr, self.live_modification_time)
+                market_status_df = self.live_data_fetchers[0].get_market_status(
+                )
+
+                self.callback(*data_arr, market_status_df,
+                              self.live_modification_time)
 
             else:
                 logging.debug('data has no change')
